from __future__ import print_function, absolute_import

from torchreid.reid.data.datasets.image.grid import GRID
from torchreid.reid.data.datasets.image.prid import PRID
from torchreid.reid.data.datasets.image.ilids import iLIDS
from torchreid.reid.data.datasets.image.viper import VIPeR
from torchreid.reid.data.datasets.image.cuhk01 import CUHK01
from torchreid.reid.data.datasets.image.cuhk02 import CUHK02
from torchreid.reid.data.datasets.image.cuhk03 import CUHK03
from torchreid.reid.data.datasets.image.msmt17 import MSMT17
from torchreid.reid.data.datasets.image.cuhksysu import CUHKSYSU
from torchreid.reid.data.datasets.image.sensereid import SenseReID
from torchreid.reid.data.datasets.image.market1501 import Market1501
from torchreid.reid.data.datasets.image.dukemtmcreid import DukeMTMCreID
from torchreid.reid.data.datasets.image.university1652 import University1652
