from __future__ import absolute_import

from torchreid.reid.engine.image.softmax import ImageSoftmaxEngine
from torchreid.reid.engine.image.triplet import ImageTripletEngine
from torchreid.reid.engine.engine import Engine
