from __future__ import print_function, absolute_import

from torchreid.reid.data.datasets.video.mars import Mars
from torchreid.reid.data.datasets.video.ilidsvid import iLIDSVID
from torchreid.reid.data.datasets.video.prid2011 import PRID2011
from torchreid.reid.data.datasets.video.dukemtmcvidreid import DukeMTMCVidReID
